﻿using SkiaSharp;
using SkiaSharp.Views.Maui.Controls;
using Microsoft.Maui.Controls;
using SkiaSharp.Views.Maui;

namespace BeSafePlus.Drawables
{
    public class RadialProgressDrawable : SKCanvasView
    {
        public static readonly BindableProperty ProgressProperty = BindableProperty.Create(
            nameof(Progress),
            typeof(float),
            typeof(RadialProgressDrawable),
            0f,
            propertyChanged: OnProgressChanged);

        public float Progress
        {
            get => (float)GetValue(ProgressProperty);
            set => SetValue(ProgressProperty, value);
        }

        public RadialProgressDrawable()
        {
            PaintSurface += OnPaintSurface;
        }
        private static void OnProgressChanged(BindableObject bindable, object oldValue, object newValue)
        {
            var drawable = (RadialProgressDrawable)bindable;

            drawable.InvalidateSurface();
        }
        private void OnPaintSurface(object sender, SKPaintSurfaceEventArgs e)
        {
            var canvas = e.Surface.Canvas;

            canvas.Save();

            canvas.Clear(SKColors.Transparent);

            var width = e.Info.Width;

            var height = e.Info.Height;

            var radius = Math.Min(width, height) / 2f * 0.95f;

            var center = new SKPoint(width / 2, height / 2);

            using (var paint = new SKPaint())
            {
                paint.Color = SKColors.LightGray;

                paint.IsAntialias = true;

                paint.StrokeWidth = 30f;

                paint.Style = SKPaintStyle.Stroke;

                canvas.DrawCircle(center, radius, paint);
            }

            using (var paint = new SKPaint())
            {
                paint.Color = SKColors.Blue;

                paint.IsAntialias = true;

                paint.StrokeWidth = 40f;

                paint.Style = SKPaintStyle.Stroke;

                paint.StrokeCap = SKStrokeCap.Round;

                float sweepAngle = 360f * Progress;

                canvas.DrawArc(
                    new SKRect(center.X - radius, center.Y - radius, center.X + radius, center.Y + radius),
                    -90,
                    sweepAngle,
                    false,
                    paint);
            }

            canvas.Restore();
        }
    }
}